==> haskell-http-client-0.6.4-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.6.4
id: http-client-0.6.4-2AUqtuWNJg2Xt7IT49doi
key: http-client-0.6.4-2AUqtuWNJg2Xt7IT49doi
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: a5bb81d9f89aab0e689e5fd7759a57bc
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-0.6.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-0.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-client-0.6.4
hs-libraries: HShttp-client-0.6.4-2AUqtuWNJg2Xt7IT49doi
depends:
    array-0.5.3.0 base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    exceptions-0.10.2-6GSxCzaG9kmCGyegXlyMgA filepath-1.4.2.1
    ghc-prim-0.5.3 http-types-0.12.3-Ge4lCiHP3W4Hc9xNIKz9xs
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    network-2.8.0.0-JWTbamlNgQDGa4CnHHLrSE
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0
    streaming-commons-0.2.1.0-FBxN4jfjoMcE9EmJ6VOheF text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.6.4-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.6.4
id: http-client-0.6.4-CphCGCPwaP0BsiFjxHzhOe
key: http-client-0.6.4-CphCGCPwaP0BsiFjxHzhOe
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: 0c4e2c2cefc9500920c26bd2c95fa300
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-0.6.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-client-0.6.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-client-0.6.4
hs-libraries: HShttp-client-0.6.4-CphCGCPwaP0BsiFjxHzhOe
depends:
    array-0.5.3.0 base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx deepseq-1.4.4.0
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH filepath-1.4.2.1
    ghc-prim-0.5.3 http-types-0.12.3-KTFxmt6v4566xpn9x45HFw
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0
    streaming-commons-0.2.1.0-HgshHrAW4sJ7tnvtY46l5k text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
